summaryrefslogtreecommitdiffstats
path: root/storage
diff options
context:
space:
mode:
authorvadimt <vadimt@chromium.org>2014-10-29 15:10:41 -0700
committerCommit bot <commit-bot@chromium.org>2014-10-29 22:11:04 +0000
commit09e7ebe02c71d923e4655a0ad5e151b97344f091 (patch)
tree116297765f286720af9aff161fafeca63486a1a6 /storage
parent2ab60d98289be5804e38ea8fdebcf78740fca095 (diff)
downloadchromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.zip
chromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.tar.gz
chromium_src-09e7ebe02c71d923e4655a0ad5e151b97344f091.tar.bz2
Switching profiler instrumentations from ScopedProfile to ScopedTracker. This will disable the instrumentations in all channels except Canary, and developer build. Instrumentations are only enabled in Browser process.
This will prevent Stable from sending increased amounts of UMA logs. Also, this will let us observe "true" (untouched by instrumentations) jankiness numbers every week in Dev channel. BUG=401560 Review URL: https://codereview.chromium.org/686963002 Cr-Commit-Position: refs/heads/master@{#301950}
Diffstat (limited to 'storage')
-rw-r--r--storage/browser/blob/local_file_stream_reader.cc6
-rw-r--r--storage/browser/blob/view_blob_internals_job.cc6
-rw-r--r--storage/browser/fileapi/local_file_stream_writer.cc6
3 files changed, 9 insertions, 9 deletions
diff --git a/storage/browser/blob/local_file_stream_reader.cc b/storage/browser/blob/local_file_stream_reader.cc
index 2ddff12..e3b827c 100644
--- a/storage/browser/blob/local_file_stream_reader.cc
+++ b/storage/browser/blob/local_file_stream_reader.cc
@@ -8,7 +8,7 @@
#include "base/files/file_util_proxy.h"
#include "base/location.h"
#include "base/logging.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/task_runner.h"
#include "net/base/file_stream.h"
#include "net/base/io_buffer.h"
@@ -102,8 +102,8 @@ void LocalFileStreamReader::DidVerifyForOpen(
void LocalFileStreamReader::DidOpenFileStream(
const net::CompletionCallback& callback,
int result) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/423948 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/423948 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"423948 LocalFileStreamReader::DidOpenFileStream"));
diff --git a/storage/browser/blob/view_blob_internals_job.cc b/storage/browser/blob/view_blob_internals_job.cc
index b9e0317..a15d2ee 100644
--- a/storage/browser/blob/view_blob_internals_job.cc
+++ b/storage/browser/blob/view_blob_internals_job.cc
@@ -11,7 +11,7 @@
#include "base/i18n/time_formatting.h"
#include "base/logging.h"
#include "base/message_loop/message_loop.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "base/strings/string_number_conversions.h"
#include "base/strings/string_util.h"
#include "base/strings/stringprintf.h"
@@ -132,8 +132,8 @@ int ViewBlobInternalsJob::GetData(
std::string* charset,
std::string* data,
const net::CompletionCallback& callback) const {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/422489 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/422489 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION("422489 ViewBlobInternalsJob::GetData"));
mime_type->assign("text/html");
diff --git a/storage/browser/fileapi/local_file_stream_writer.cc b/storage/browser/fileapi/local_file_stream_writer.cc
index 968b5fe..c6a1d51 100644
--- a/storage/browser/fileapi/local_file_stream_writer.cc
+++ b/storage/browser/fileapi/local_file_stream_writer.cc
@@ -6,7 +6,7 @@
#include "base/callback.h"
#include "base/message_loop/message_loop.h"
-#include "base/profiler/scoped_profile.h"
+#include "base/profiler/scoped_tracker.h"
#include "net/base/file_stream.h"
#include "net/base/io_buffer.h"
#include "net/base/net_errors.h"
@@ -126,8 +126,8 @@ void LocalFileStreamWriter::DidOpen(
const net::CompletionCallback& error_callback,
const base::Closure& main_operation,
int result) {
- // TODO(vadimt): Remove ScopedProfile below once crbug.com/423948 is fixed.
- tracked_objects::ScopedProfile tracking_profile(
+ // TODO(vadimt): Remove ScopedTracker below once crbug.com/423948 is fixed.
+ tracked_objects::ScopedTracker tracking_profile(
FROM_HERE_WITH_EXPLICIT_FUNCTION(
"423948 LocalFileStreamWriter::DidOpen"));